﻿using System;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace demoLeitoraUsb
{
    public partial class Form1 : Form
    {
        // **Extrutura "TAcionador"
        public struct TAcionador
        {
            public int Tipo;
            public int Serial3d;
            public int Serial7d;
            public int Contador;
            public int Bateria;
            public int Botao;
        }

        // **Importação da DLL "LeitoraUSB.dll"
        [DllImport("LeitoraUSB.dll")]
        public static extern TAcionador LerAcionador(int tipo_serial);

        public Form1()
        {
            InitializeComponent();

            // Valor padrão do ComboBox
            cbTipoSerial.SelectedIndex = 0;
        }

        // **Função auxiliar para formatação do serial
        public string formataSerial(int f, int s3d, int s7d)
        {
            string ret = "";

            switch (f)
            {
                // 7 dígitos
                case 0:
                case 1:
                    ret = s7d.ToString("X7");
                    break;
                // 10 dígitos
                case 2:
                    ret = s3d.ToString("X3") + s7d.ToString("X7");
                    break;
            }

            return ret;
        }

        private void btOnOff_Click(object sender, EventArgs e)
        {
            // Botão "Habilita"

            if (btOnOff.Text == "Habilita")
            {
                cbTipoSerial.Enabled = false;
                tLendo.Enabled = true;

                btOnOff.Text = "Desabilita";
            }
            else //if (btOnOff.Text == "Desabilita")
            {
                cbTipoSerial.Enabled = true;
                tLendo.Enabled = false;

                btOnOff.Text = "Habilita";
            }
        }

        private void tLendo_Tick(object sender, EventArgs e)
        {
            // Timer 250 ms

            TAcionador ret;
            int formato = cbTipoSerial.SelectedIndex;

            tLendo.Enabled = false;

            ret = LerAcionador(formato);

            if (ret.Tipo != 0)
            {
                lbInfo.Text = "- - - -";
                tbSerial.Clear();
                tbConta.Clear();
                lbBat.Text = "- - - -";
                lbBot.Text = "- - - -";
            }

            switch (ret.Tipo)
            {
                case -2:
                    lbInfo.Text = "Erro!";
                    break;

                case -1:
                    lbInfo.Text = "Não conectada!";
                    break;

                case 1:
                    lbInfo.Text = "Controle remoto (TX)";
                    tbSerial.Text = formataSerial(formato, ret.Serial3d, ret.Serial7d);
                    tbConta.Text = ret.Contador.ToString("X4");

                    if (ret.Bateria == 0)
                        lbBat.Text = "BOA";
                    else
                        lbBat.Text = "FRACA";
                    
                    lbBot.Text = ret.Botao.ToString();
                    break;

                case 2:
                    lbInfo.Text = "TAG Ativo (TA)";
                    tbSerial.Text = formataSerial(formato, ret.Serial3d, ret.Serial7d);

                    if (ret.Bateria == 0)
                        lbBat.Text = "BOA";
                    else
                        lbBat.Text = "FRACA";
                    break;

                case 3:
                    lbInfo.Text = "Cartão de proximidade (CT)";
                    tbSerial.Text = formataSerial(formato, ret.Serial3d, ret.Serial7d);
                    break;

                case 8:
                    lbInfo.Text = "Entrada Wiegand";
                    tbSerial.Text = formataSerial(formato, ret.Serial3d, ret.Serial7d);
                    break;

                case 9:
                    lbInfo.Text = "Entrada RS-485";
                    tbSerial.Text = formataSerial(formato, ret.Serial3d, ret.Serial7d);
                    break;
            }

            tLendo.Enabled = true;
        }

        private void textBox1_Click(object sender, EventArgs e)
        {
            textBox1.SelectAll();
        }

        private void textBox2_Enter(object sender, EventArgs e)
        {
            textBox2.SelectAll();
        }

        private void textBox3_Enter(object sender, EventArgs e)
        {
            textBox3.SelectAll();
        }

    }
}
